# orchMI I/O interface
# author: Milan Lstiburek
# see Instructions.txt

#xxx Load libraries xxx
library(xlsx)
library(orchMI)

#xxx Options xxx
clone_ID <- 1 #1...consecutive numbers, 0...clonal ID's provided in .xlsx sheet IDMAT (column 3)
NIT <- 500 #number of iterations of the QAP heuristics
XY <- 1  #ratio of the x/y planting distance

#xxx 1 - Files xxx
setwd("D:/CZU/R_code/SO_designs/My_R_libraries/orchMI/orchard/IO_files")
inp_file <- "orchMI_import.xlsx"
exp_file <- "orchMI_export.xlsx"

#xxx Input from Excel xxx
inp_1 <- read.xlsx(inp_file, sheetName = "GRMAT", header = FALSE) # read the GRMAT sheet
GRMAT <- apply(as.matrix.noquote(inp_1),2,as.numeric)
inp_2 <- read.xlsx(inp_file, sheetName = "IDMAT", header = FALSE) # read the GRMAT sheet
x_1 <- apply(as.matrix.noquote(inp_2),2,as.character)
x_2 <- x_1[,1:2]
IDMAT <- mapply(x_2, FUN=as.numeric)
IDMAT <- matrix(data=IDMAT, ncol=2)
if (clone_ID == 0) rownames(IDMAT) <- x_1[,3]
inp_3 <- read.xlsx(inp_file, sheetName = "GMAT", header = FALSE) # read the GMAT sheet
GMAT <- apply(as.matrix.noquote(inp_3),2,as.numeric)

#xxx Calculate the MI scheme xxx
MI <- orchMI(ID = IDMAT, GR = GRMAT, GM = GMAT, xy = XY, rep = NIT, miter = 2 * nrow(GRMAT), fiter = 1.1, ft = 0.5
, maxsteps = 50L)

#xxx Output to Excel xxx
if (clone_ID == 0) y_1 <- apply(as.matrix.noquote(MI),2,as.character)
if (clone_ID == 1) y_1 <- apply(as.matrix.noquote(MI),2,as.numeric)
write.xlsx(y_1, exp_file, sheetName = "MI", col.names = FALSE, row.names = FALSE)

#xxx Clear directory xxx
rm(list=setdiff(ls(), "MI"))
